@@ -2,7 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 from common import *
 from datetime_strftime import *
-from domain_inversion import domain_inversion, eval_domain, localize_domain, \
-        merge, inverse_leaf, filter_leaf, concat, simplify, unique_value
+from .domain_inversion import domain_inversion, eval_domain, localize_domain, \
+        merge, inverse_leaf, filter_leaf, prepare_reference_domain, \
+        extract_reference_models, concat, simplify, unique_value
 from environment import EvalEnvironment
 import timedelta
