@@ -1,7 +1,5 @@
 # This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-import gtk
-
 import tryton.common as common
 
 
@@ -28,9 +26,6 @@ class NoModal(object):
 
     def destroy(self):
         self.page.dialogs.remove(self)
-        # Test if the parent is not already destroyed
-        if self.parent not in gtk.window_list_toplevels():
-            return
         self.parent.present()
         self.sensible_widget.props.sensitive = True
         for focus in self.parent_focus:
