@@ -240,7 +240,7 @@ class Screen(SignalEvent):
         return list(self.domain_parser.completion(search_string))
 
     def search_filter(self, search_string=None, only_ids=False):
-        if self.context_screen:
+        if self.context_screen and not only_ids:
             context_record = self.context_screen.current_record
             if not context_record.validate():
                 self.clear()
@@ -740,7 +740,6 @@ class Screen(SignalEvent):
                 and not view.attributes.get('tree_state', False)):
             # Mark as done to not set later when the view_type change
             self.tree_states_done.add(id(view))
-            return
         parent = self.parent.id if self.parent else None
         if parent is not None and parent < 0:
             return
@@ -790,8 +789,6 @@ class Screen(SignalEvent):
         self.tree_states_done.add(id(view))
 
     def save_tree_state(self, store=True):
-        if not CONFIG['client.save_tree_state']:
-            return
         parent = self.parent.id if self.parent else None
         timestamp = self.parent._timestamp if self.parent else None
         for view in self.views:
@@ -812,7 +809,9 @@ class Screen(SignalEvent):
                 selected_paths = view.get_selected_paths()
                 self.tree_states[parent][view.children_field] = (
                     timestamp, paths, selected_paths)
-                if store and view.attributes.get('tree_state', False):
+                if (store
+                        and int(view.attributes.get('tree_state', False))
+                        and CONFIG['client.save_tree_state']):
                     json_domain = self.get_tree_domain(parent)
                     json_paths = json.dumps(paths, separators=(',', ':'))
                     json_selected_path = json.dumps(
@@ -917,25 +916,29 @@ class Screen(SignalEvent):
             self.current_record = record
         elif view.view_type == 'calendar':
             record = self.current_record
-            goocalendar = view.widgets['goocalendar']
-            date = goocalendar.selected_date
-            year = date.year
-            month = date.month
-            start = datetime.datetime(year, month, 1)
-            nb_days = calendar.monthrange(year, month)[1]
-            delta = datetime.timedelta(days=nb_days)
-            end = start + delta
-            events = goocalendar.event_store.get_events(start, end)
-            events.sort()
-            if not record:
-                self.current_record = len(events) and events[0].record
-            else:
-                for idx, event in enumerate(events):
-                    if event.record == record:
-                        next_id = idx + 1
-                        if next_id < len(events):
-                            self.current_record = events[next_id].record
-                        break
+            goocalendar = view.widgets.get('goocalendar')
+            if goocalendar:
+                date = goocalendar.selected_date
+                year = date.year
+                month = date.month
+                start = datetime.datetime(year, month, 1)
+                nb_days = calendar.monthrange(year, month)[1]
+                delta = datetime.timedelta(days=nb_days)
+                end = start + delta
+                events = goocalendar.event_store.get_events(start, end)
+                events.sort()
+                if not record:
+                    if events:
+                        self.current_record = events[0].record
+                    else:
+                        self.current_record = None
+                else:
+                    for idx, event in enumerate(events):
+                        if event.record == record:
+                            next_id = idx + 1
+                            if next_id < len(events):
+                                self.current_record = events[next_id].record
+                            break
         else:
             self.current_record = self.group[0] if len(self.group) else None
         self.set_cursor(reset_view=False)
@@ -974,25 +977,29 @@ class Screen(SignalEvent):
             self.current_record = record
         elif view.view_type == 'calendar':
             record = self.current_record
-            goocalendar = view.widgets['goocalendar']
-            date = goocalendar.selected_date
-            year = date.year
-            month = date.month
-            start = datetime.datetime(year, month, 1)
-            nb_days = calendar.monthrange(year, month)[1]
-            delta = datetime.timedelta(days=nb_days)
-            end = start + delta
-            events = goocalendar.event_store.get_events(start, end)
-            events.sort()
-            if not record:
-                self.current_record = len(events) and events[0].record
-            else:
-                for idx, event in enumerate(events):
-                    if event.record == record:
-                        prev_id = idx - 1
-                        if prev_id >= 0:
-                            self.current_record = events[prev_id].record
-                        break
+            goocalendar = view.widgets.get('goocalendar')
+            if goocalendar:
+                date = goocalendar.selected_date
+                year = date.year
+                month = date.month
+                start = datetime.datetime(year, month, 1)
+                nb_days = calendar.monthrange(year, month)[1]
+                delta = datetime.timedelta(days=nb_days)
+                end = start + delta
+                events = goocalendar.event_store.get_events(start, end)
+                events.sort()
+                if not record:
+                    if events:
+                        self.current_record = events[0].record
+                    else:
+                        self.current_record = None
+                else:
+                    for idx, event in enumerate(events):
+                        if event.record == record:
+                            prev_id = idx - 1
+                            if prev_id >= 0:
+                                self.current_record = events[prev_id].record
+                            break
         else:
             self.current_record = self.group[-1] if len(self.group) else None
         self.set_cursor(reset_view=False)
